package dev.fyloz.trial.colorrecipesexplorer.core.services.files;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.io.ResourceLoader;
import org.springframework.stereotype.Service;
import org.springframework.util.FileCopyUtils;

import java.io.IOException;
import java.io.InputStream;
import java.nio.charset.StandardCharsets;

@Service
public class FilesService {

    private ResourceLoader resources;

    @Autowired
    public FilesService(ResourceLoader resources) {
        this.resources = resources;
    }

    /**
     * Lit un fichier dans le dossier resources.
     *
     * @param path Le chemin vers la fichier (sans classpath:, depuis le dossier resources)
     * @return Le contenu du fichier
     */
    public String readResourceFile(String path) {
        String fullPath = String.format("classpath:%s", path);
        try (InputStream stream = resources.getResource(fullPath).getInputStream()) {
            return readInputStreamAsString(stream);
        } catch (IOException e) {
            e.printStackTrace();
            return null;
        }
    }

    /**
     * Lit un InputStream et le transforme en String
     *
     * @param input L'InputStream
     * @return Le InputStream transformé en String
     * @throws IOException Si la transformation vers un String échoue
     */
    public String readInputStreamAsString(InputStream input) throws IOException {
        byte[] data = FileCopyUtils.copyToByteArray(input);
        return new String(data, StandardCharsets.UTF_8);
    }

}
